<?php

namespace App\Controller;

use App\Entity\CaseDocument;
use App\Entity\CompanyDocument;
use App\Entity\MemberCase;
use App\Entity\User;
use App\Libs\NavList;
use App\Libs\Libs;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Security\Http\Attribute\CurrentUser;

class DocumentController extends AbstractController
{
    public function __construct(
        private EntityManagerInterface $entityManager,
        private array $navLinks = []
    ) {
        $this->navLinks = NavList::LIST;
    }

    #[Route('/case/{caseId}/doc/{docId}', name: 'app_display_case_doc')]
    public function displayCaseDocument(string $caseId, string $docId, #[CurrentUser()] User $user): Response
    {
        $case = $this->entityManager->getRepository(MemberCase::class)->find($caseId);
        $doc = $this->entityManager->getRepository(CompanyDocument::class)->find($docId);
        $caseDoc = $this->entityManager->getRepository(CaseDocument::class)->getCaseDocument($case, $doc);

        return $this->render(
            'internal/cases/documents/display-case-doc.html.twig',
            array_merge(
                $this->navLinks,
                [
                    'msgs' => Libs::getMessages($user, $this->entityManager),
                    'breadcrumbs' => []
                ]
            )
        );
    }
}